server_client_20141231_085104

### config1 : test_load_balance

Result | Function execution time | Total execution time
--- | --- | ---
Passed | 4.04002904892 sec | 5.76795196533 sec

Naarad report

### Metrics

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 112.51 | 77.06 | 58.74 | 59.94 | 86.22 | 101.99 | 107.25 | 111.45 | 25.07
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | 4.0
server1-perf | latency | p50 lt 0.3 | 0.6245
server1-perf | latency | mean lt 0.33 | 1.84516666667
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | 1.0
client1-perf | latency | p50 lt 22.0 | 59.943
client1-perf | latency | mean lt 35.0 | 77.0623333333
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None